@@ -10,7 +10,7 @@ push @ISA, 'Exporter';
 BEGIN {
   require Exporter;
   @ISA = qw(Exporter);
-  $VERSION = '0.004';
+  $VERSION = '0.005';
   eval {
     # try XSLoader first, DynaLoader has annoying baggage
     require XSLoader;
@@ -94,8 +94,10 @@ sub screenshot {
     Imager->_set_error(Imager->_error_as_msg());
     return;
   }
-  
-  return $result;
+
+  # RT #24992 - the Imager typemap entry is broken pre-0.56, so
+  # wrap it here
+  return bless { IMG => $result }, "Imager";
 }
 
 sub have_win32 {
@@ -321,6 +323,24 @@ generated by my window manager.
 
 Imager::Screenshot is licensed under the same terms as Perl itself.
 
+=head1 TODO
+
+Future plans include:
+
+=over
+
+=item *
+
+OS X support - I need to find out which APIs to use to do this
+
+=item *
+
+window name searches - currently screenshot() requires a window
+identifier of some sort, it would be more usable if we could supply
+some other identifier, either a window title or a window class name.
+
+=back
+
 =head1 AUTHOR
 
 Tony Cook <tonyc@cpan.org>
